# -*- coding: utf-8 -*-

class AppNotFoundError(Exception):
    def __init__(self, name):
        self.name = name

    def __str__(self):
        return f'Application {self.name} not found'

class ContainerNotFoundError(Exception):
    def __init__(self, name):
        self.name = name

    def __str__(self):
        return f'Container {self.name} not found'

class ImageNotFoundError(Exception):
    def __init__(self, name):
        self.name = name

    def __str__(self):
        return f'Image {self.name} not found'

class InvalidContainerStateError(Exception):
    # Container is not in expected state (running, stopped etc.)
    def __init__(self, container_name, container_state):
        self.container_name = container_name
        self.container_state = container_state

    def __str__(self):
        return f'Container "{self.container_name}" reached unexpected state {self.container_state}'

class CircularDependencyError(Exception):
    # Dependecy solver has found a circular dependency between nodes
    def __init__(self, deps):
        self.deps = deps

    def __str__(self):
        result = ['Dependency resolution failed due to circular dependency. Dumping unresolved dependencies:']
        result.extend(f'{dep} => {node.depends}' for dep, node in self.deps.items())
        return '\n'.join(result)
